@@ -11,7 +11,7 @@ from tqdm import tqdm
 
 BASE_PATH = os.path.join(os.path.expanduser("~"), ".objaverse")
 
-__version__ = "0.0.5"
+__version__ = "0.0.7"
 _VERSIONED_PATH = os.path.join(BASE_PATH, "hf-objaverse-v1")
 
 
@@ -23,9 +23,16 @@ def load_annotations(uids: Optional[List[str]] = None) -> List[Dict[str, Any]]:
         the metadata for all uids.
     """
     metadata_path = os.path.join(_VERSIONED_PATH, "metadata")
+    object_paths = _load_object_paths()
+    dir_ids = (
+        set([object_paths[uid].split("/")[1] for uid in uids])
+        if uids is not None
+        else [f"{i // 1000:03d}-{i % 1000:03d}" for i in range(160)]
+    )
+    if len(dir_ids) > 10:
+        dir_ids = tqdm(dir_ids)
     out = {}
-    for i in tqdm(range(160)):
-        i_id = f"{i // 1000:03d}-{i % 1000:03d}"
+    for i_id in dir_ids:
         json_file = f"{i_id}.json.gz"
         local_path = os.path.join(metadata_path, json_file)
         if not os.path.exists(local_path):
@@ -89,14 +96,16 @@ def _download_object(
         The local path of where the object was downloaded.
     """
     # print(f"downloading {uid}")
-    local_path = os.path.join(_VERSIONED_PATH, object_path + ".tmp")
+    local_path = os.path.join(_VERSIONED_PATH, object_path)
+    tmp_local_path = os.path.join(_VERSIONED_PATH, object_path + ".tmp")
     hf_url = (
         f"https://huggingface.co/datasets/allenai/objaverse/resolve/main/{object_path}"
     )
     # wget the file and put it in local_path
-    os.makedirs(os.path.dirname(local_path), exist_ok=True)
-    urllib.request.urlretrieve(hf_url, local_path)
-    os.rename(local_path, local_path[: -len(".tmp")])
+    os.makedirs(os.path.dirname(tmp_local_path), exist_ok=True)
+    urllib.request.urlretrieve(hf_url, tmp_local_path)
+
+    os.rename(tmp_local_path, local_path)
 
     files = glob.glob(os.path.join(_VERSIONED_PATH, "glbs", "*", "*.glb"))
     print(
@@ -202,6 +211,7 @@ if __name__ == "__main__":
     uids = [k for k, v in object_paths.items() if v.startswith("glbs/000-000")][
         500:1000
     ]
+    load_annotations(uids)
     print(f"Loaded {len(uids)} uids")
     objects = load_objects(uids, download_processes=10)
     print(f"Loaded {len(objects)} objects")
